"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Popover = void 0;

var _react = _interopRequireDefault(require("react"));

var _Overlay = require("../Overlay/Overlay");

var _hooks = require("../hooks");

var _Popper = require("../Popper/Popper");

var _OverlayBackdrop = require("../Overlay/OverlayBackdrop");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const Popover = props => {
  let triggerRef = _react.default.useRef(null);

  const [isOpen, setIsOpen] = (0, _hooks.useControllableState)({
    defaultValue: props.defaultIsOpen,
    value: props.isOpen,
    onChange: props.onOpenChange
  });

  const handleOpen = () => {
    setIsOpen(true);
  };

  const handleClose = () => {
    setIsOpen(false);
  };

  let triggerElem = null; // Received a trigger ref

  if (props.trigger.hasOwnProperty('current')) {
    // @ts-ignore
    triggerRef = props.trigger;
  } // Received a trigger element
  else if ( /*#__PURE__*/_react.default.isValidElement(props.trigger)) {
      const triggerExistingProps = props.trigger.props; // Trigger won't be changes in rerenders, so this seems safe
      // eslint-disable-next-line react-hooks/rules-of-hooks

      const handlers = (0, _hooks.useOn)({
        on: props.on,
        onClose: handleClose,
        onOpen: handleOpen,
        ...triggerExistingProps
      });
      triggerElem = /*#__PURE__*/_react.default.cloneElement(props.trigger, {
        ref: triggerRef,
        ...handlers
      });
    } else {
      console.warn(`Popover: Invalid 'trigger' prop received, please pass a valid ReactElement or a Ref`);
    }

  const {
    mode = 'popover'
  } = props;
  const {
    triggerProps,
    contentProps
  } = (0, _hooks.usePopover)({
    isOpen,
    mode
  });

  if (triggerElem) {
    triggerElem = /*#__PURE__*/_react.default.cloneElement(triggerElem, { ...triggerProps
    });
  }

  const isHoverTriggerEvent = props.on === 'hover';

  let focusProps = _react.default.useMemo(() => {
    return {
      trapFocus: !isHoverTriggerEvent,
      autoFocus: !isHoverTriggerEvent,
      restoreFocus: !isHoverTriggerEvent
    };
  }, [isHoverTriggerEvent]);

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, triggerElem, /*#__PURE__*/_react.default.createElement(_Overlay.Overlay, _extends({
    isOpen: isOpen,
    onClose: handleClose,
    isKeyboardDismissable: props.isKeyboardDismissable,
    mode: mode
  }, focusProps), /*#__PURE__*/_react.default.createElement(_Popper.Popper, _extends({}, props, {
    onClose: handleClose,
    triggerRef: triggerRef,
    contentProps: contentProps
  }))));
};

exports.Popover = Popover;
Popover.Content = _Popper.Popper.Content;
Popover.Arrow = _Popper.Popper.Arrow;
Popover.Backdrop = _OverlayBackdrop.OverlayBackdrop;
//# sourceMappingURL=Popover.js.map