import React from 'react';
import ReactDOM from 'react-dom';
import { StyleSheet, View } from 'react-native';
import { useKeyboardDismissable } from '../hooks';
import { FocusScope } from '@react-native-aria/focus';
import { OverlayContext } from './context';
export function Overlay(props) {
  const {
    isOpen,
    children,
    autoFocus = true,
    restoreFocus = true,
    trapFocus = true,
    onClose,
    isKeyboardDismissable = true,
    mode = 'popover'
  } = props;
  useKeyboardDismissable({
    enabled: isKeyboardDismissable,
    onClose: onClose ? onClose : () => {}
  });

  if (!isOpen) {
    return null;
  }

  let content = /*#__PURE__*/React.createElement(OverlayContext.Provider, {
    value: {
      onClose
    }
  }, /*#__PURE__*/React.createElement(View, {
    style: StyleSheet.absoluteFill,
    pointerEvents: "box-none"
  }, mode === 'popover' ? /*#__PURE__*/React.createElement(FocusScope, {
    contain: trapFocus,
    autoFocus: autoFocus,
    restoreFocus: restoreFocus
  }, children) : children));
  return /*#__PURE__*/ReactDOM.createPortal(content, document.body);
}
//# sourceMappingURL=Overlay.web.js.map