function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { Overlay } from '../Overlay/Overlay';
import { useControllableState, useOn, usePopover } from '../hooks';
import { Popper } from '../Popper/Popper';
import { OverlayBackdrop } from '../Overlay/OverlayBackdrop';

const Popover = props => {
  let triggerRef = React.useRef(null);
  const [isOpen, setIsOpen] = useControllableState({
    defaultValue: props.defaultIsOpen,
    value: props.isOpen,
    onChange: props.onOpenChange
  });

  const handleOpen = () => {
    setIsOpen(true);
  };

  const handleClose = () => {
    setIsOpen(false);
  };

  let triggerElem = null; // Received a trigger ref

  if (props.trigger.hasOwnProperty('current')) {
    // @ts-ignore
    triggerRef = props.trigger;
  } // Received a trigger element
  else if ( /*#__PURE__*/React.isValidElement(props.trigger)) {
      const triggerExistingProps = props.trigger.props; // Trigger won't be changes in rerenders, so this seems safe
      // eslint-disable-next-line react-hooks/rules-of-hooks

      const handlers = useOn({
        on: props.on,
        onClose: handleClose,
        onOpen: handleOpen,
        ...triggerExistingProps
      });
      triggerElem = /*#__PURE__*/React.cloneElement(props.trigger, {
        ref: triggerRef,
        ...handlers
      });
    } else {
      console.warn(`Popover: Invalid 'trigger' prop received, please pass a valid ReactElement or a Ref`);
    }

  const {
    mode = 'popover'
  } = props;
  const {
    triggerProps,
    contentProps
  } = usePopover({
    isOpen,
    mode
  });

  if (triggerElem) {
    triggerElem = /*#__PURE__*/React.cloneElement(triggerElem, { ...triggerProps
    });
  }

  const isHoverTriggerEvent = props.on === 'hover';
  let focusProps = React.useMemo(() => {
    return {
      trapFocus: !isHoverTriggerEvent,
      autoFocus: !isHoverTriggerEvent,
      restoreFocus: !isHoverTriggerEvent
    };
  }, [isHoverTriggerEvent]);
  return /*#__PURE__*/React.createElement(React.Fragment, null, triggerElem, /*#__PURE__*/React.createElement(Overlay, _extends({
    isOpen: isOpen,
    onClose: handleClose,
    isKeyboardDismissable: props.isKeyboardDismissable,
    mode: mode
  }, focusProps), /*#__PURE__*/React.createElement(Popper, _extends({}, props, {
    onClose: handleClose,
    triggerRef: triggerRef,
    contentProps: contentProps
  }))));
};

Popover.Content = Popper.Content;
Popover.Arrow = Popper.Arrow;
Popover.Backdrop = OverlayBackdrop;
export { Popover };
//# sourceMappingURL=Popover.js.map